==> 1.2.10.zip: 9iron/startpage/index.php <==
<html>
	<head>
		<?php include $_SERVER['DOCUMENT_ROOT'].'/src/common-meta.php';?>
		<link href="/startpage/styles/styles.css" type="text/css" rel="stylesheet"/>
		<title>New Tab</title>
	</head>
	<body>
		<div class="header">
			<form class="search-form" id="sp-search-form" action="https://www.startpage.com/do/dsearch" method="post">
				<input type="text" name="query" class="search-input" placeholder="search" autofocus />
			</form>
		</div>
		<div class="content">
			<!-- LABBITY -->
			<div class="spsection">
				<div class="spsubsection">
					<h4>Quicklinks</h4>
					<a href="https://nc.desu.ltd/index.php/apps/files">Files</a>
					<a href="https://nc.desu.ltd/index.php/apps/calendar">Calendar</a>
					<a href="https://nc.desu.ltd/index.php/apps/news">Feed</a>
				</div>
				<div class="spsubsection">
					<h4>desu.ltd</h4>
					<a href="https://desu.ltd">Index</a>
					<a href="https://git.desu.ltd">Gitea</a>
					<a href="https://netbox.desu.ltd">Netbox</a>
				</div>
				<div class="spsubsection">
					<h4>Others</h4>
					<a href="https://9iron.club">9iron</a>
					<a href="http://local.desu.ltd">Localnet</a>
				</div>
				<div class="spsubsection">
					<h4>Resources</h4>
					<a href="https://console.aws.amazon.com">AWS Dashboard</a>
					<a href="https://domains.google.com/">Google Domains</a>
					<a href="https://cloud.linode.com/dashboard">Linode Dashboard</a>
				</div>
			</div>
			<!-- FUN -->
			<div class="spsection">
				<div class="spsubsection">
					<h4>Fedi</h4>
					<a href="https://cowfee.moe">Cowfee</a>
					<a href="https://tube.seriousposter.club/r/seriousposters#">SPCTube</a>
				</div>
				<div class="spsubsection">
					<h4>Imageboards</h4>
					<a href="https://8chan.moe">8chan.moe</a>
					<a href="https://smuglo.li">smuglo.li</a>
				</div>
				<div class="spsubsection">
					<h4>Projects</h4>
					<a href="https://itazuraneko.neocities.org/learn/guide.html">Learn Japanese</a>
				</div>
				<div class="spsubsection">
					<h4>Other</h4>
					<a href="https://tcrf.net">TCRF</a>
					<a href="http://www.vgmpf.com">VGMPF</a>
					<a href="https://git.axiodl.com/AxioDL/urde">URDE</a>
				</div>
			</div>
			<div class="quote"><?php include $_SERVER['DOCUMENT_ROOT'].'/src/common-inspiration.php';?></div>
		</div>
		<?php include $_SERVER['DOCUMENT_ROOT'].'/src/common-footer.php';?>
	</body>
</html>

==> 1.3.2.zip: 9iron/startpage/index.php <==
<html>
	<head>
		<?php include $_SERVER['DOCUMENT_ROOT'].'/src/common-meta.php';?>
		<link href="/startpage/styles/styles.css" type="text/css" rel="stylesheet"/>
		<title>New Tab</title>
	</head>
	<body>
		<div class="header">
			<form class="search-form" id="sp-search-form" action="https://www.startpage.com/do/dsearch" method="post">
				<input type="text" name="query" class="search-input" placeholder="search" autofocus />
			</form>
		</div>
		<div class="content">
			<!-- LABBITY -->
			<div class="spsection">
				<div class="spsubsection">
					<h4>Quicklinks</h4>
					<a href="https://nc.desu.ltd/index.php/apps/files">Files</a>
					<a href="https://nc.desu.ltd/index.php/apps/calendar">Calendar</a>
					<a href="https://nc.desu.ltd/index.php/apps/news">Feed</a>
				</div>
				<div class="spsubsection">
					<h4>desu.ltd</h4>
					<a href="https://git.desu.ltd">Gitea</a>
					<a href="https://netbox.desu.ltd">Netbox</a>
					<a href="https://nagios.desu.ltd">Nagios</a>
				</div>
				<div class="spsubsection">
					<h4>Others</h4>
					<a href="https://9iron.club">9iron</a>
					<a href="http://local.desu.ltd">Localnet</a>
				</div>
				<div class="spsubsection">
					<h4>Resources</h4>
					<a href="https://console.aws.amazon.com">AWS Dashboard</a>
					<a href="https://domains.google.com/">Google Domains</a>
					<a href="https://cloud.linode.com/dashboard">Linode Dashboard</a>
				</div>
			</div>
			<!-- FUN -->
			<div class="spsection">
				<div class="spsubsection">
					<h4>Fedi</h4>
					<a href="https://cowfee.moe">Cowfee</a>
					<a href="https://tube.seriousposter.club/r/seriousposters#">SPCTube</a>
				</div>
				<div class="spsubsection">
					<h4>Imageboards</h4>
					<a href="https://8chan.moe">8chan.moe</a>
					<a href="https://smuglo.li">smuglo.li</a>
				</div>
				<div class="spsubsection">
					<h4>Projects</h4>
					<a href="https://itazuraneko.neocities.org/learn/guide.html">Learn Japanese</a>
				</div>
				<div class="spsubsection">
					<h4>Other</h4>
					<a href="https://tcrf.net">TCRF</a>
					<a href="http://www.vgmpf.com">VGMPF</a>
					<a href="https://git.axiodl.com/AxioDL/urde">URDE</a>
				</div>
			</div>
			<div class="quote"><?php include $_SERVER['DOCUMENT_ROOT'].'/src/common-inspiration.php';?></div>
		</div>
		<?php include $_SERVER['DOCUMENT_ROOT'].'/src/common-footer.php';?>
	</body>
</html>
